If a vector is passed as an argument, then poly((x) is a vector of the
coefficients of the polynomial whose roots are the elements of x.
If an \(N x N\) square matrix is given, poly((x)
is the row vector of the coefficients of det (z * diag (N) - x),
which is the characteristic polynomial of x.